.. _simba:

Evolvable SimBa
===============

An evolvable version of the SimBa architecture following the paper `SimBa: Simplicity Bias for Scaling Up Parameters in Deep Reinforcement Learning <https://arxiv.org/abs/2410.09754>`_ .

Parameters
------------

.. autoclass:: agilerl.modules.simba.EvolvableSimBa
  :members:
